##  Subscriptions Management Report
The subscription management report provides an overview of all subscriptions, summarizing the total number of subscriptions for each user. This report allows you to manage subscriptions effectively, with options to delete or transfer them as needed.
Admins can find it under the Reports section in the administration area. By clicking the Show Report icon (eye icon), you can make the report visible to all users in the Reports tab of the workspace.
![Accessing Subscriptions Management Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2746cd2e7a441014ae67b61424fd6b98_LowRes.png)
Accessing Subscriptions Management Report
In the report you can sort and filter the list of users by their status and user role, distinguish between active and inactive users, and make necessary transfers of subscriptions as needed.
![Subscriptions Management Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2751fda67a44101483159707b1bff82f_LowRes.png)
Subscriptions Management Report
To get detailed information about a user's subscriptions, click on the number of subscriptions associated with that user. This will display a breakdown of all fact sheets to which the user is subscribed, providing details on subscription type and the specific subscription roles.
![Subscription details of a user](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2741c9737a441014a8818dd2b9d672a9_LowRes.png)
Subscription Details of a User
